********************************************************************************

*Figure 2, 3, 4

********************************************************************************		

sum b1_logprice
gen b_wt=b1_logprice/r(mean)
cap drop x_bar- stateid
egen x_bar=mean(new_logprice), by( statefip)
gen xdem=new_logprice-x_bar
egen zbar=mean(new_logtax), by(statefip)
gen zdem= new_logtax-zbar
gen xzdem=xdem*zdem
egen xzdemst=sum(xzdem), by(statefip)
egen temp=sum(xzdemst) if  pickone2_1==1 
egen xzdemtot=mean(temp)  
gen xz_wt=xzdemst/xzdemtot
replace xz_wt=-xz_wt
drop temp xzdemtot
cap gen zero=0
sort wt
egen stateid=min(round(_n/360)), by(statefip)
labmask stateid, values(statename)


************** Figure 2: Weighting under FEIV and PCIV Approaches **************

twoway bar xz_wt stateid if pickone2_1==1 , horizontal || bar wt stateid if pickone2_1==1 , horizontal, ///
|| sc stateid zero, mlabel(stateid)  mlabcolor(black) msymbol(i) mlabsize(tiny) ///
legend( lab(1 "Relative First-Stage Variation") lab(2 "Relative Sales Volume")  lab(3 " ") ) ///
 ytitle("") plotregion(style(none)) ylab(none) ///
graphregion(fcolor(white) ifcolor(white)) plotregion(fcolor(white) ifcolor(white))
graph export "relative_weights.png", as(png) replace


******** Figure 3: State-Specific First- and Second-Stage Coefficients *********

twoway bar b1_logprice stateid2 if pickone2_1==1 , horizontal || bar first_1_b1_logtax stateid2 if pickone2_1==1 , horizontal ///
|| sc stateid2 zero, legend(lab( 1 "Second-stage coefficients") lab(2 "First-stage coefficients") lab(3 "")) ///
mlabel(stateid2)  mlabcolor(black) msymbol(i) mlabsize(tiny) ///
 ytitle("") graphregion(fcolor(white) ifcolor(white)) plotregion(fcolor(white) ifcolor(white))
graph export "state_elasticities.png", as(png) replace


******* Figure 4: Hetefogeneous Elasticities and First-Stage Variation *********

egen temp=mean(xzdemst) if  pickone2_1==1 
egen xzdemtot=mean(temp)  
gen xz_wt2=xzdemst/xzdemtot
*reg xz_wt2 b_wt if  pickone2_1==1 [aw=wt]

twoway (scatter xz_wt2 b_wt   if  pickone2_1==1  [aw=wt], msize(tiny)) (lfit   xz_wt2 b_wt if  pickone2_1==1 [aw=wt]), ytitle("Relative First-Stage Variation") ///
xtitle("Relative Elasticity") graphregion(fcolor(white) ifcolor(white)) plotregion(fcolor(white) ifcolor(white))
graph export "violation.png", as(png) replace

********************************************************************************

*Figure D.1. Sensitivity of Elasticity Estimates

********************************************************************************		
clear

use "pub_trans.dta", clear

sort state year month

bysort statefip: egen freq = total(statetax != statetax[_n-1] & _n > 1)
bysort statefip: gen size = statetax-statetax[_n-1] if statetax != statetax[_n-1] & _n > 1
bysort statefip: egen sum_size=total(size)

bysort statefip: gen size_price = logprice-logprice[_n-1] if logprice != logprice[_n-1] & _n > 1
bysort statefip: egen sum_size_price=total(size_price)

replace freq=log(freq)
replace sum_size=log(sum_size)
replace pub_tran=log(pub_tran)
replace sum_size_price=log(sum_size_price)

regress sum_size pub_tran if year==1989 & month==1

local beta: display %5.3f _b[pub_tran]

twoway (scatter sum_size pub_tran) (lfit sum_size pub_tran), legend(off) ///
xtitle("Log(Avg. Number of People Using Public Transportation in 1980)", size(vsmall)) ytitle("Total Sum of State Tax Changes") note(Slope Coefficient=`beta') ///
graphregion(fcolor(white) ifcolor(none) style(none)) bgcolor(none) plotregion(fcolor(none) ifcolor(none) style(none)) name(size_pub_tran, replace)
graph export "sum_pub_tran.png", as(png) replace



********************************************************************************

*Figure E.1. Sensitivity of Elasticity Estimates

********************************************************************************		

clear 
use App_results4_22.dta, clear
keep if _n==1
ren w_reg* reg*_w
ren w_se* se*_w
keep reg* se*
gen i=_n
foreach i in 1 2 4 5 6 {
ren reg`i'_* reg_*`i'
ren se`i'_* se_*`i'
}
drop *1
foreach i in fe 2sls{
ren reg_elasticity_`i'# reg_elasticity_`i'_nw#
ren se_elasticity_`i'# se_elasticity_`i'_nw#
}
ren reg_elasticity# reg_elasticity_pciv_nw#
ren reg_elasticity_w# reg_elasticity_pciv_w#
ren se_elasticity# se_elasticity_pciv_nw#
ren se_elasticity_w# se_elasticity_pciv_w#

reshape long reg_elasticity_pciv_w reg_elasticity_pciv_nw se_elasticity_pciv_nw se_elasticity_pciv_w ///
reg_elasticity_fe_w reg_elasticity_fe_nw se_elasticity_fe_nw se_elasticity_fe_w ///
reg_elasticity_2sls_w reg_elasticity_2sls_nw se_elasticity_2sls_nw se_elasticity_2sls_w , i(i) j(model)

reshape long reg_elasticity_pciv se_elasticity_pciv ///
reg_elasticity_fe se_elasticity_fe ///
reg_elasticity_2sls se_elasticity_2sls , i(model) j(weighted) string

sort model weighted
egen mw=group(model weighted)

twoway (connected reg_elasticity_2sls mw , lp(dash) msymbol(circle)) (connected reg_elasticity_fe mw , lp(dash_dot) msymbol(square)) ///
(connected reg_elasticity_pciv mw , lp(solid) msymbol(triangle)),  subtitle("volume weighted (W), unweighted (UW), leads (LD),  lags (LG)") ///
xlab(1 "Base (UW)" 2 "Base (W)" 3 "Base+LG (UW) " 4 "Base+LG (W)" 5 "Base+LD (UW)" 6 "Base+LD (W)" 7 "Base+LD+LG (UW) " 8 "Base+LD+LG (W)" , angle(45)) ///
xtitle("Specifications")  legend(title("Estimators") r(1) lab(1 "P2SLS") lab(2 "FEIV") lab(3 "PCIV")) ///
graphregion(fcolor(white) ifcolor(white)) plotregion(fcolor(white) ifcolor(white))
graph export "sensitivity.png", as(png) replace
