********************************************************************************

*Table 3: Estimated Elasticities (LATE Analysis)

********************************************************************************		

foreach i in 1 2 {
clear
clear mata
clear matrix
set maxvar 30000
use App_results`i'.dta, clear
keep statefip time first_fstat_1_`i' first_w_fstat_1_`i' x_hat`i'_* pickone`i'_1 *_x_hat_dem`i'
save fstat.dta, replace
merge 1:1 statefip time using temp_all.dta, gen(mrgFstat)

*Leave the states with only strong instrument.
drop if first_fstat_1_`i'<10

egen pickone`i'=tag(statefip)
sum pickone`i' if pickone`i'==1
local clust=r(N) 

if `i'==1 {

*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;
dis "Regression 1 - without covariates"
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;

local dcovars_rt ""
local dcovars_miss_rt ""
local  new_covars ""
local  new_covars_miss ""
local  covars ""
local  covars_miss ""
local ivlist dlogtax_rt
local endoglist "dlogprice_rt"
local new_ivlist "new_logtax"
local new_endoglist "new_logprice"
local pc_ivlist "logtax"
local pc_endoglist "logprice"
local options ""
local lincomlist "dlogprice_rt"
local new_lincomlist "new_logprice"
local pc_lincomlist "logprice"
local rf_lincomlist "dlogtax_rt"
local rf_new_lincomlist "new_logtax"
local rf_pc_lincomlist "logtax"


}

if `i'==2 {
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;
dis "Regression 2 - with covariates"
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;

local dcovars_rt real_inc_pc_rt population_rt licensed_rt road_m_rt dmy_min_temp_rt dmy_avg_temp_rt dmy_max_temp_rt dmy_rain_in_rt dunemployment_rt
local dcovars_miss_rt real_inc_pc_miss_rt population_miss_rt licensed_miss_rt road_m_miss_rt dmy_min_temp_miss_rt dmy_avg_temp_miss_rt dmy_max_temp_miss_rt dmy_rain_in_miss_rt
local  new_covars new_real_inc_pc new_population new_licensed new_road_m new_my_min_temp new_my_avg_temp new_my_max_temp new_my_rain_in new_unemployment
local  new_covars_miss new_real_inc_pc_miss new_population_miss new_licensed_miss new_road_m_miss new_my_min_temp_miss new_my_avg_temp_miss new_my_max_temp_miss new_my_rain_in_miss
local  covars real_inc_pc population licensed road_m dmy_min_temp dmy_avg_temp dmy_max_temp dmy_rain_in unemployment
local  covars_miss real_inc_pc_miss population_miss licensed_miss road_m_miss dmy_min_temp_miss dmy_avg_temp_miss dmy_max_temp_miss dmy_rain_in_miss
local ivlist dlogtax_rt
local endoglist "dlogprice_rt"
local new_ivlist "new_logtax"
local new_endoglist "new_logprice"
local pc_ivlist "logtax"
local pc_endoglist "logprice"
local options ""
local lincomlist "dlogprice_rt"
local new_lincomlist "new_logprice"
local pc_lincomlist "logprice"
local rf_lincomlist "dlogtax_rt"
local rf_new_lincomlist "new_logtax"
local rf_pc_lincomlist "logtax"


}



********************************** P2SLS ***************************************

/* without weights */

estimates clear

*** first and second stage ***

eststo reg_2sls: qui ivreg2 dlogvolume_rt `dcovars_rt' `dcovars_miss_rt' (`endoglist' = `ivlist'), cluster(statefip) savefirst saverf savefprefix( reg_2sls_f_) saverfprefix( reg_2sls_rf_) 
lincom `lincomlist' 

local reg_elasticity_2sls = r(estimate)
local se_elasticity_2sls = r(se)
gen reg_elasticity_2sls`i' = r(estimate)
gen se_elasticity_2sls`i' = r(se)

*** reduced form ***

est res reg_2sls_rf_*

lincom `rf_lincomlist'

estadd local rf_reg_elasticity_2sls = r(estimate)
estadd local rf_se_elasticity_2sls = r(se)

qui ivreg2 dlogvolume_rt `dcovars_rt' `dcovars_miss_rt' (`endoglist' = `ivlist'), cluster(statefip) 
local fstat_cd_2sls=e(widstat)
gen fstat_cd_2sls`i'=e(widstat)


/* with weights */

*** first and second stage ***

eststo reg_2sls_w: qui ivreg2 dlogvolume_rt `dcovars_rt' `dcovars_miss_rt' (`endoglist' = `ivlist') [pweight=wt], cluster(statefip) savefirst saverf savefprefix( reg_2sls_w_f_) saverfprefix( reg_2sls_w_rf_) 

lincom `lincomlist' 

local reg_elasticity_2sls_w = r(estimate)
local se_elasticity_2sls_w = r(se)

gen reg_elasticity_2sls_w`i' = r(estimate)
gen se_elasticity_2sls_w`i' = r(se)

*** reduced form ***

est res reg_2sls_w_rf_*

lincom `rf_lincomlist'

estadd local rf_w_reg_elasticity_2sls = r(estimate)
estadd local rf_w_se_elasticity_2sls = r(se)

qui ivreg2 dlogvolume_rt `dcovars_rt' `dcovars_miss_rt' (`endoglist' = `ivlist') [pweight=wt], cluster(statefip) 
local fstat_cd_2sls_w=e(widstat)
gen fstat_cd_2sls_w`i'=e(widstat)


********************************** FEIV ****************************************

/* without weights */

*** first and second stage ***

xtset statefip time
eststo reg_fe: qui xtivreg2 new_logvolume `new_covars' `new_covars_miss' (`new_endoglist'=`new_ivlist'), savefirst saverf savefprefix(reg_fe_f_) saverfprefix( reg_fe_rf_)  fe small cluster(statefip) 
lincom `new_lincomlist' 

local reg_elasticity_fe = r(estimate)
local se_elasticity_fe = r(se)

gen reg_elasticity_fe`i' = r(estimate)
gen se_elasticity_fe`i' = r(se)

*** reduced form ***

est res reg_fe_rf_*

lincom `rf_new_lincomlist'

local rf_reg_elasticity_fe = r(estimate)
local rf_se_elasticity_fe = r(se)

qui xtivreg2 new_logvolume `new_covars' `new_covars_miss' (`new_endoglist'=`new_ivlist'), fe cluster(statefip) 
local fstat_cd_fe=e(widstat)
gen fstat_cd_fe`i'=e(widstat)


/* with weights */

*** first and second stage ***

xtset statefip time
eststo reg_fe_w: qui xtivreg2 new_logvolume `new_covars' `new_covars_miss' (`new_endoglist'=`new_ivlist') [pweight=wt], fe cluster(statefip)  savefirst saverf savefprefix( reg_fe_w_f_) saverfprefix( reg_fe_w_rf_) 

lincom `new_lincomlist' 

local reg_elasticity_fe_w = r(estimate)
local se_elasticity_fe_w = r(se)

gen reg_elasticity_fe_w`i' = r(estimate)
gen se_elasticity_fe_w`i' = r(se)

*** reduced form ***

est res reg_fe_w_rf_*

lincom `rf_new_lincomlist'

estadd local rf_w_reg_elasticity_fe = r(estimate)
estadd local rf_w_se_elasticity_fe = r(se)

qui xtivreg2 new_logvolume `new_covars' `new_covars_miss' (`new_endoglist'=`new_ivlist') [pweight=wt], cluster(statefip) fe savefirst saverf savefprefix( reg_fe_w_f) saverfprefix( reg_fe_w_rf) 
local fstat_cd_fe_w=e(widstat)
gen fstat_cd_fe_w`i'=e(widstat)



********************************** PCIV ****************************************

/* without weights */

*** second stage ***

foreach var of varlist `pc_endoglist' {
qui gen b`i'_`var'=.
}
qui gen b`i'_cons=.

qui gen yhat`i'=.

* first obtain the residuals by regressing y and x2 on x1_hat per cluster
qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg logvolume x_hat`i'_* if statefip==`k'
qui predict yhat`i'_`k', resid
qui replace yhat`i' = yhat`i'_`k' if statefip==`k'
}

drop yhat`i'_*

foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat {

qui gen `exog'_2hat`i'=.

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg `exog' x_hat`i'_* if statefip==`k'
qui predict `exog'_2hat`i'_`k', resid
qui replace `exog'_2hat`i' = `exog'_2hat`i'_`k' if statefip==`k'
}

drop `exog'_2hat`i'_*

}

* regress residualized y on residualized x2. Then, obtain y_breve = y - delta_hat*x2

qui reg yhat`i' *_2hat`i'
foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat {
qui gen y_breve`i'_b_`exog'=_b[`exog'_2hat`i']
}

qui gen y_breve`i' = logvolume
foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat {
qui replace y_breve`i'= y_breve`i' - (y_breve`i'_b_`exog'*`exog')
}

* reg y_breve on x1_hat per cluster

qui gen resid`i'= y_breve`i'

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
 
qui reg y_breve`i' x_hat`i'_* if statefip==`k'
local m=1
foreach var of varlist `pc_endoglist' {
qui replace b`i'_`var'=_b[x_hat`i'_`m'] if statefip==`k'
qui replace resid`i'=resid`i'-b`i'_`var'*`var' if statefip==`k'
local m `++m'
}
}

*standard errors
foreach var of varlist `pc_endoglist' {
qui gen sum_errors`i'_`var'=.
}

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
mkmat x_hat`i'_* if statefip==`k'  `options', matrix(X) 
mkmat resid`i' if statefip==`k' `options', matrix(e)
matrix xx=X'*X
matrix xe=X'*e
matrix sum_comp=invsym(xx)*xe
local j=1
foreach var of varlist `pc_endoglist' {
local d`j'=sum_comp[`j',1]
qui replace sum_errors`i'_`var'=`d`j'' if statefip==`k'
local j `++j'
}
}

foreach var of varlist `pc_endoglist' {
egen reg`i'_`var' = mean(b`i'_`var')
qui gen dhat`i'_`var'=b`i'_`var'-reg`i'_`var'
}

qui gen reg`i'_elasticity=0

foreach var of varlist `pc_endoglist' {
egen var`i'_dhat_`var'=sd(dhat`i'_`var') if pickone`i'_1==1
egen var`i'_`var'=sd(sum_errors`i'_`var') if pickone`i'_1==1
qui gen se`i'_`var'=sqrt((var`i'_dhat_`var'^2+var`i'_`var'^2)/`clust')
qui gen t`i'_`var'=reg`i'_`var'/se`i'_`var'
qui replace reg`i'_elasticity=reg`i'_elasticity+reg`i'_`var'
}

corr sum_errors`i'_* if pickone`i'_1==1, c
mat sum_errors`i'=r(C)/`clust'

corr dhat`i'_* if pickone`i'_1==1, c
mat dhat_errors`i'=r(C)/`clust'

mat errors`i'=sum_errors`i'+dhat_errors`i'

mata: st_matrix("var`i'", rowsum(colsum(st_matrix("errors`i'"))))
qui gen var`i'_elasticity=var`i'[1,1]
qui gen se`i'_elasticity=sqrt(var`i'_elasticity)
qui gen t`i'_elasticity=reg`i'_elasticity/se`i'_elasticity

*** reduced form ***

foreach var of varlist `pc_ivlist' {
qui gen rf_b`i'_`var'=.
}
qui gen rf_b`i'_cons=.
qui gen rf_yhat`i'=.

* first obtain the residuals by regressing y and x2 on Z
qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg logvolume `pc_ivlist' if statefip==`k'
qui predict rf_yhat`i'_`k', resid
qui replace rf_yhat`i' = rf_yhat`i'_`k' if statefip==`k'
}

drop rf_yhat`i'_*

* regress residualized y on residualized x2. Then, obtain rf_y_breve = y - delta_hat*x2

qui reg rf_yhat`i' *_x_hat_dem`i'
foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat {
qui gen rf_y_breve`i'_b_`exog'=_b[`exog'_x_hat_dem`i']
}

qui gen rf_y_breve`i' = logvolume
foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat {
qui replace rf_y_breve`i'= rf_y_breve`i' - (rf_y_breve`i'_b_`exog'*`exog')
}

* reg rf_y_breve on Z per cluster

qui gen rf_resid`i'=rf_y_breve`i'

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
 
qui reg rf_y_breve`i' `pc_ivlist' if statefip==`k'

foreach var of varlist `pc_ivlist' {
qui replace rf_b`i'_`var'=_b[`var'] if statefip==`k'
qui replace rf_resid`i'=rf_resid`i'-rf_b`i'_`var'*`var' if statefip==`k'
}
}

*standard errors
foreach var of varlist `pc_ivlist' {
qui gen rf_sum_errors`i'_`var'=.
}

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
mkmat `pc_ivlist' if statefip==`k' `options', matrix(Z) 
mkmat rf_resid`i' if statefip==`k' `options', matrix(e)
matrix zz=Z'*Z
matrix ze=Z'*e
matrix sum_comp=invsym(zz)*ze
local j=1
foreach var of varlist `pc_ivlist' {
local d`j'=sum_comp[`j',1]
qui replace rf_sum_errors`i'_`var'=`d`j'' if statefip==`k'
local j `++j'
}
}

foreach var of varlist `pc_ivlist' {
egen rf_reg`i'_`var' = mean(rf_b`i'_`var')
qui gen rf_dhat`i'_`var'=rf_b`i'_`var'-rf_reg`i'_`var'
}

qui gen rf_reg`i'_elasticity=0

foreach var of varlist `pc_ivlist' {
egen rf_var`i'_dhat_`var'=sd(rf_dhat`i'_`var') if pickone`i'_1==1
egen rf_var`i'_`var'=sd(rf_sum_errors`i'_`var') if pickone`i'_1==1
qui gen rf_se`i'_`var'=sqrt((rf_var`i'_dhat_`var'^2+rf_var`i'_`var'^2)/`clust')
qui gen rf_t`i'_`var'=rf_reg`i'_`var'/rf_se`i'_`var'
qui replace rf_reg`i'_elasticity=rf_reg`i'_elasticity+rf_reg`i'_`var'
}

corr rf_sum_errors`i'_* if pickone`i'_1==1, c
mat rf_sum_errors`i'=r(C)/`clust'

corr rf_dhat`i'_* if pickone`i'_1==1, c
mat rf_dhat_errors`i'=r(C)/`clust'

mat rf_errors`i'=rf_sum_errors`i'+rf_dhat_errors`i'

mata: st_matrix("rf_var`i'", rowsum(colsum(st_matrix("rf_errors`i'"))))
qui gen rf_var`i'_elasticity=rf_var`i'[1,1]
qui gen rf_se`i'_elasticity=sqrt(rf_var`i'_elasticity)
qui gen rf_t`i'_elasticity=rf_reg`i'_elasticity/rf_se`i'_elasticity

/* with weights */

gen wt_sq=sum(wt^2) if pickone`i'_1==1
replace wt_sq=sqrt(wt_sq) if pickone`i'_1==1

*** second stage ***

foreach var of varlist `pc_endoglist' {
egen w_reg`i'_`var'=wtmean(b`i'_`var'), weight(wt)
qui gen w_dhat`i'_`var'=wt*(b`i'_`var'-w_reg`i'_`var')
qui gen w_sum_errors`i'_`var'=wt*sum_errors`i'_`var'
}

qui gen w_reg`i'_elasticity=0

foreach var of varlist `pc_endoglist' {
qui gen w_se`i'_`var'=wt_sq*se`i'_`var'*sqrt(`clust')
qui gen w_t`i'_`var'=w_reg`i'_`var'/w_se`i'_`var'
qui replace w_reg`i'_elasticity=w_reg`i'_elasticity+w_reg`i'_`var'
}

qui gen w_se`i'_elasticity=wt_sq*se`i'_elasticity*sqrt(`clust')
qui gen w_t`i'_elasticity=w_reg`i'_elasticity/w_se`i'_elasticity

*** reduced form ***

 foreach var of varlist `pc_ivlist' {
egen rf_w_reg`i'_`var'=wtmean(rf_b`i'_`var'), weight(wt)
qui gen rf_w_dhat`i'_`var'=wt*(rf_b`i'_`var'-rf_w_reg`i'_`var')
qui gen rf_w_sum_errors`i'_`var'=wt*rf_sum_errors`i'_`var'
}

qui gen rf_w_reg`i'_elasticity=0

foreach var of varlist `pc_ivlist' {
qui gen rf_w_se`i'_`var'=wt_sq*rf_se`i'_`var'*sqrt(`clust')
qui gen rf_w_t`i'_`var'=rf_w_reg`i'_`var'/rf_w_se`i'_`var'
qui replace rf_w_reg`i'_elasticity=rf_w_reg`i'_elasticity+rf_w_reg`i'_`var'
}

qui gen rf_w_se`i'_elasticity=wt_sq*rf_se`i'_elasticity*sqrt(`clust')
qui gen rf_w_t`i'_elasticity=rf_w_reg`i'_elasticity/rf_w_se`i'_elasticity


**Results

outreg2 [reg_2sls reg_fe reg_2sls_w reg_fe_w] using "reg`i'_second_LATE.xls", replace ///
addstat("Elasticity_2SLS", `reg_elasticity_2sls',"se",`se_elasticity_2sls',"Elasticity_FE", `reg_elasticity_fe',"se", `se_elasticity_fe',"Elasticity_2SLS_W", `reg_elasticity_2sls_w',"se",`se_elasticity_2sls_w',"Elasticity_FE_W", `reg_elasticity_fe_w',"se",`se_elasticity_fe_w') excel nor2 dec(3) nocons drop(dunemployment_rt new_unemployment) cttop("2SLS", "FE", "2SLS_W", "FE_W")

*second stage PCIV
fsum reg*logprice se*logprice t*logprice w_reg*logprice w_se*logprice w_t*logprice reg*elasticity* w_reg*elasticity* se*elasticity w_se*elasticity, stat(mean)  f(%9.3f)

save App_results`i'LATE.dta, replace


}


********************************************************************************

*Table 3: Estimated Elasticities Table (LATE Analysis)

********************************************************************************		

use App_results1LATE.dta, clear
keep statename statefip time year month *reg* *se* *elasticity* *fstat*

foreach i in reg se {
sum `i'_elasticity_2sls1
mat `i'a=(r(mean))
sum `i'_elasticity_fe1
mat `i'a=(`i'a,r(mean))
sum `i'1_elasticity
mat `i'a=(`i'a,r(mean))
sum `i'_elasticity_2sls_w1
mat `i'a=(`i'a,r(mean))
sum `i'_elasticity_fe_w1
mat `i'a=(`i'a,r(mean))
sum w_`i'1_elasticity
mat `i'a=(`i'a,r(mean))
}

foreach i in fstat {
sum `i'_cd_2sls1
mat `i'a=(r(mean))
sum `i'_cd_fe1
mat `i'a=(`i'a,r(mean))
sum first_`i'_1_1
mat `i'a=(`i'a,r(mean))
sum `i'_cd_2sls_w1
mat `i'a=(`i'a,r(mean))
sum `i'_cd_fe_w1
mat `i'a=(`i'a,r(mean))
sum first_w_`i'_1_1
mat `i'a=(`i'a,r(mean))

}
mat rownames rega= "Log price"
mat rownames fstata= "First-stage F-statistic"
mat rownames sea= " "


frmttable using "LATE.tex", statmat(rega) replace  tex  ///
	ctitles(" ", "Without volume weights", "", "","Volume weighted", "", "" \"", "P2SLS","FEIV","PCIV","P2SLS","FEIV","PCIV" )  ///
	sdec(3, 3, 3, 3,3,3  )  multicol(1,2,3;1,5,3)
	frmttable using "LATE.tex", statmat(sea) append va tex  ///
	ctitles(" ", "Without volume weights", "", "","Volume weighted", "", "" \"", "P2SLS","FEIV","PCIV","P2SLS","FEIV","PCIV" )  ///
	dbldiv(" (") brackets("(",")") ///
	sdec(3, 3, 3, 3,3,3  ) addrows( " "," "," "," "," ", " ")  multicol(1,2,3;1,5,3)
	frmttable using "LATE.tex", statmat(fstata) append va tex ///
	ctitles(" ", "Without volume weights", "", "","Volume weighted", "", "" \"", "P2SLS","FEIV","PCIV","P2SLS","FEIV","PCIV" )  ///
	addrows( " "," "," "," "," ", " ") ///
		sdec(2, 2, 2, 2,2,2 )  multicol(1,2,3;1,5,3)

