********************************************************************************

*Table D.4. Regression: Estimated Elasticities Using Month and Year Fixed Effects

********************************************************************************		


use new_app.dta, clear

*qui generate a data dummy and t2 and t3

qui gen dat=0
qui replace dat=1 if (year==2008 & month>3 | year>2008) 
qui tab time, generate(tm)
qui tab year, gen(tmy)
qui tab month, gen(tmm)

*Few Last Definitions;
qui gen dunemployment = d.unemployment
qui gen TwoCentIncrease=(dstatetax>=2 & dstatetax!=.)
qui gen TwoCentDecrease=(dstatetax<=-2 & dstatetax!=.)
qui gen Iincrease = TwoCentIncrease * dlogtax

* IV using residual projection method;
foreach x of varlist dlogvolume dlogprice  dlogtax dunemployment {
 quietly reg `x' i.year i.month
 qui predict `x'_rt, residuals
 quietly reg f.`x' i.year i.month
 qui predict f1`x'_rt, residuals
 quietly reg f2.`x' i.year i.month
 qui predict f2`x'_rt, residuals
 quietly reg l.`x' i.year i.month
 qui predict l1`x'_rt, residuals
 quietly reg l2.`x' i.year i.month
 qui predict l2`x'_rt, residuals
 quietly reg l3.`x' i.year i.month
 qui predict l3`x'_rt, residuals
}

foreach x of varlist logvolume logprice logtax unemployment {
 quietly reg `x' i.year i.month 
 qui predict new_`x', residuals
 quietly reg l.`x' i.year i.month 
 qui predict lnew_`x', residuals
 quietly reg f.`x' i.year i.month 
 qui predict fnew_`x', residuals
 quietly reg f2.`x' i.year i.month
 qui predict f2new_`x', residuals
 quietly reg l2.`x' i.year i.month
 qui predict l2new_`x', residuals
 }
 
 foreach x of varlist logvolume logprice logtax unemployment {
 qui gen f`x'=f.`x'
 qui gen f2`x'=f2.`x'
 qui gen l`x'=l.`x'
 qui gen l2`x'=l2.`x'
 }

bysort statefip: egen avg_volume=mean(volume)
egen tot=total(avg_volume)
qui gen wt=avg_volume*360/tot

save temp_all.dta, replace



forval i=2/2 {

use temp_all.dta, clear

if `i'==2 {
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;
dis "Regression without covariates"
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;

local ivlist "dlogtax_rt"
local endoglist "dlogprice_rt"
local new_ivlist "new_logtax"
local new_endoglist "new_logprice"
local pc_ivlist "logtax"
local pc_endoglist "logprice"
local options ""
local lincomlist "dlogprice_rt"
local new_lincomlist "new_logprice"
local pc_lincomlist "logprice"
local rf_lincomlist "dlogtax_rt"
local rf_new_lincomlist "new_logtax"
local rf_pc_lincomlist "logtax"

}

********************************** P2SLS ***************************************

/* without weights */

estimates clear
clear matrix
clear mata

*** first and second stage ***

eststo reg_2sls: qui ivreg2 dlogvolume_rt  (`endoglist' = `ivlist'), cluster(statefip) savefirst saverf savefprefix( reg_2sls_f_) saverfprefix( reg_2sls_rf_) 
lincom `lincomlist' 

local reg_elasticity_2sls = r(estimate)
local se_elasticity_2sls = r(se)
gen reg_elasticity_2sls`i' = r(estimate)
gen se_elasticity_2sls`i' = r(se)

*** reduced form ***

est res reg_2sls_rf_*

lincom `rf_lincomlist'

estadd local rf_reg_elasticity_2sls = r(estimate)
estadd local rf_se_elasticity_2sls = r(se)

qui ivreg2 dlogvolume_rt  (`endoglist' = `ivlist'), cluster(statefip) 
local fstat_cd_2sls=e(widstat)
gen fstat_cd_2sls`i'=e(widstat)
/* with weights */

*** first and second stage ***

eststo reg_2sls_w: qui ivreg2 dlogvolume_rt  (`endoglist' = `ivlist') [pweight=wt], cluster(statefip) savefirst saverf savefprefix( reg_2sls_w_f_) saverfprefix( reg_2sls_w_rf_) 

lincom `lincomlist' 

local reg_elasticity_2sls_w = r(estimate)
local se_elasticity_2sls_w = r(se)

gen reg_elasticity_2sls_w`i' = r(estimate)
gen se_elasticity_2sls_w`i' = r(se)

*** reduced form ***

est res reg_2sls_w_rf_*

lincom `rf_lincomlist'

estadd local rf_w_reg_elasticity_2sls = r(estimate)
estadd local rf_w_se_elasticity_2sls = r(se)

qui ivreg2 dlogvolume_rt  (`endoglist' = `ivlist') [pweight=wt], cluster(statefip) 
local fstat_cd_2sls_w=e(widstat)
gen fstat_cd_2sls_w`i'=e(widstat)

********************************** FEIV ****************************************

/* without weights */

*** first and second stage ***

xtset statefip time
eststo reg_fe:  xtivreg2 new_logvolume  (`new_endoglist'=`new_ivlist'),   savefirst saverf savefprefix(reg_fe_f_) saverfprefix( reg_fe_rf_)  fe small cluster(statefip) 
lincom `new_lincomlist' 

local reg_elasticity_fe = r(estimate)
local se_elasticity_fe = r(se)

gen reg_elasticity_fe`i' = r(estimate)
gen se_elasticity_fe`i' = r(se)

*** reduced form ***

est res reg_fe_rf_*

lincom `rf_new_lincomlist'

local rf_reg_elasticity_fe = r(estimate)
local rf_se_elasticity_fe = r(se)

 xtivreg2 new_logvolume  (`new_endoglist'=`new_ivlist'), fe cluster(statefip) 
local fstat_cd_fe=e(widstat)
di `fstat_cd_fe'
gen fstat_cd_fe`i'=e(widstat)

/* with weights */

*** first and second stage ***

xtset statefip time
eststo reg_fe_w:  xtivreg2 new_logvolume  (`new_endoglist'=`new_ivlist') [pweight=wt], fe cluster(statefip)  savefirst saverf savefprefix( reg_fe_w_f_) saverfprefix( reg_fe_w_rf_) 

lincom `new_lincomlist' 

local reg_elasticity_fe_w = r(estimate)
local se_elasticity_fe_w = r(se)
gen reg_elasticity_fe_w`i' = r(estimate)
gen se_elasticity_fe_w`i' = r(se)

*** reduced form ***

est res reg_fe_w_rf_*

lincom `rf_new_lincomlist'

estadd local rf_w_reg_elasticity_fe = r(estimate)
estadd local rf_w_se_elasticity_fe = r(se)

 xtivreg2 new_logvolume  (`new_endoglist'=`new_ivlist') [pweight=wt], fe cluster(statefip) 
local fstat_cd_fe_w=e(widstat)
di `fstat_cd_fe_w'
gen fstat_cd_fe_w`i'=e(widstat)


********************************** PCIV ****************************************

/* without weights */

*** first stage ***

* getting the residuals by regressing x1 and x2 on Z


foreach exog of varlist  tmy1-tmy30 tmm1-tmm12 dat {

qui gen `exog'_x_hat_dem`i'=. 

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg  `exog' `pc_ivlist' if statefip==`k'
qui predict `exog'_x_hat_dem`i'_`k', resid
qui replace `exog'_x_hat_dem`i' = `exog'_x_hat_dem`i'_`k' if statefip==`k'
}

drop `exog'_x_hat_dem`i'_*
}

local m=1
foreach endo of varlist `pc_endoglist' {
qui gen x_hat_dem`i'_`m'=. 
qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg  `endo' `pc_ivlist' if statefip==`k'
qui predict x_hat_dem`i'_`m'_`var'_`k', resid
qui replace x_hat_dem`i'_`m' = x_hat_dem`i'_`m'_`var'_`k' if statefip==`k'
}

drop x_hat_dem`i'_`m'_*


* regress residualized x1 on residualized x2, then obtain x1_tilde = x1 - delta_hat*x2
qui reg x_hat_dem`i'_`m' *_x_hat_dem`i'
foreach exog of varlist  tmy1-tmy30 tmm1-tmm12 dat {
qui gen x_tilde`i'_`m'_b_`exog'=_b[`exog'_x_hat_dem`i']
}

qui gen x_tilde`i'_`m' = `endo'
foreach exog of varlist  tmy1-tmy30 tmm1-tmm12 dat {
qui replace x_tilde`i'_`m'= x_tilde`i'_`m' - (x_tilde`i'_`m'_b_`exog'*`exog')
}

foreach var of varlist `pc_ivlist' {
qui gen first_`m'_b`i'_`var'=.
}
qui gen first_`m'_resid`i'=x_tilde`i'_`m'

* reg x1_tilde on z
qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg  x_tilde`i'_`m' `pc_ivlist' if statefip==`k'

* get the estimates from the first stage
foreach var of varlist `pc_ivlist' {
qui replace first_`m'_b`i'_`var'=_b[`var'] if statefip==`k'
qui replace first_`m'_resid`i'=first_`m'_resid`i'-first_`m'_b`i'_`var'*`var' if statefip==`k'
}
}

* recover the x_hat by adding gamma_hat*x2
qui gen x_hat`i'_`m'=0
foreach var of varlist `pc_ivlist' {
qui replace x_hat`i'_`m'= x_hat`i'_`m' + first_`m'_b`i'_`var'*`var'
}

foreach exog of varlist  tmy1-tmy30 tmm1-tmm12 dat {
qui replace x_hat`i'_`m' = x_hat`i'_`m' + x_tilde`i'_`m'_b_`exog'*`exog'
}

*f-stats

statsby temp_first_fstat_`m'_`i'=e(F), by(statefip) saving(statsby`i'_`m', replace): reg x_tilde`i'_`m' `pc_ivlist'

sort statefip
merge m:1 statefip using statsby`i'_`m'
capture egen pickone`i'_`m' = tag(statefip)
drop _merge 

hotelling temp_first_fstat_`m'_`i' if pickone`i'_1==1

qui gen first_fstat_`m'_`i'=r(T2)


*standard errors
foreach var of varlist `pc_ivlist' {
egen first_`m'_reg`i'_`var' = mean(first_`m'_b`i'_`var')
qui gen first_`m'_dhat`i'_`var'=first_`m'_b`i'_`var'-first_`m'_reg`i'_`var'
qui gen first_`m'_sum_errors`i'_`var'=.
}

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
mkmat `pc_ivlist' if statefip==`k' `options', matrix(Z) 
mkmat first_`m'_resid`i' if statefip==`k' `options', matrix(e)
matrix zz=Z'*Z
matrix ze=Z'*e
matrix sum_comp=invsym(zz)*ze
local j=1
foreach var of varlist `pc_ivlist' {
local d`j'=sum_comp[`j',1]
qui replace first_`m'_sum_errors`i'_`var'=`d`j'' if statefip==`k'
local j `++j'
}
}
foreach var of varlist `pc_ivlist' {
egen first_`m'_var`i'_dhat_`var'=sd(first_`m'_dhat`i'_`var') if pickone`i'_1==1
egen first_`m'_var`i'_`var'=sd(first_`m'_sum_errors`i'_`var') if pickone`i'_1==1
qui gen first_`m'_se`i'_`var'=sqrt((first_`m'_var`i'_dhat_`var'^2+first_`m'_var`i'_`var'^2)/51)
qui gen first_`m'_t`i'_`var'=first_`m'_reg`i'_`var'/first_`m'_se`i'_`var'
}
local m `++m'
}

*** second stage ***

foreach var of varlist `pc_endoglist' {
qui gen b`i'_`var'=.
}
qui gen b`i'_cons=.

qui gen yhat`i'=.

* first obtain the residuals by regressing y and x2 on x1_hat per cluster
qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg logvolume x_hat`i'_* if statefip==`k'
qui predict yhat`i'_`k', resid
qui replace yhat`i' = yhat`i'_`k' if statefip==`k'
}

drop yhat`i'_*

foreach exog of varlist  tmy1-tmy30 tmm1-tmm12 dat {

qui gen `exog'_2hat`i'=.

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg `exog' x_hat`i'_* if statefip==`k'
qui predict `exog'_2hat`i'_`k', resid
qui replace `exog'_2hat`i' = `exog'_2hat`i'_`k' if statefip==`k'
}

drop `exog'_2hat`i'_*

}

* regress residualized y on residualized x2. Then, obtain y_breve = y - delta_hat*x2

qui reg yhat`i' *_2hat`i'
foreach exog of varlist  tmy1-tmy30 tmm1-tmm12 dat {
qui gen y_breve`i'_b_`exog'=_b[`exog'_2hat`i']
}

qui gen y_breve`i' = logvolume
foreach exog of varlist  tmy1-tmy30 tmm1-tmm12 dat {
qui replace y_breve`i'= y_breve`i' - (y_breve`i'_b_`exog'*`exog')
}

* reg y_breve on x1_hat per cluster

qui gen resid`i'= y_breve`i'

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
 
qui reg y_breve`i' x_hat`i'_* if statefip==`k'
local m=1
foreach var of varlist `pc_endoglist' {
qui replace b`i'_`var'=_b[x_hat`i'_`m'] if statefip==`k'
qui replace resid`i'=resid`i'-b`i'_`var'*`var' if statefip==`k'
local m `++m'
}
}

*standard errors
foreach var of varlist `pc_endoglist' {
qui gen sum_errors`i'_`var'=.
}

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
mkmat x_hat`i'_* if statefip==`k'  `options', matrix(X) 
mkmat resid`i' if statefip==`k' `options', matrix(e)
matrix xx=X'*X
matrix xe=X'*e
matrix sum_comp=invsym(xx)*xe
local j=1
foreach var of varlist `pc_endoglist' {
local d`j'=sum_comp[`j',1]
qui replace sum_errors`i'_`var'=`d`j'' if statefip==`k'
local j `++j'
}
}

foreach var of varlist `pc_endoglist' {
egen reg`i'_`var' = mean(b`i'_`var')
qui gen dhat`i'_`var'=b`i'_`var'-reg`i'_`var'
}

qui gen reg`i'_elasticity=0

foreach var of varlist `pc_endoglist' {
egen var`i'_dhat_`var'=sd(dhat`i'_`var') if pickone`i'_1==1
egen var`i'_`var'=sd(sum_errors`i'_`var') if pickone`i'_1==1
qui gen se`i'_`var'=sqrt((var`i'_dhat_`var'^2+var`i'_`var'^2)/51)
qui gen t`i'_`var'=reg`i'_`var'/se`i'_`var'
qui replace reg`i'_elasticity=reg`i'_elasticity+reg`i'_`var'
}

corr sum_errors`i'_* if pickone`i'_1==1, c
mat sum_errors`i'=r(C)/51

corr dhat`i'_* if pickone`i'_1==1, c
mat dhat_errors`i'=r(C)/51

mat errors`i'=sum_errors`i'+dhat_errors`i'

mata: st_matrix("var`i'", rowsum(colsum(st_matrix("errors`i'"))))
qui gen var`i'_elasticity=var`i'[1,1]
qui gen se`i'_elasticity=sqrt(var`i'_elasticity)
qui gen t`i'_elasticity=reg`i'_elasticity/se`i'_elasticity

*** reduced form ***

foreach var of varlist `pc_ivlist' {
qui gen rf_b`i'_`var'=.
}
qui gen rf_b`i'_cons=.
qui gen rf_yhat`i'=.

* first obtain the residuals by regressing y and x2 on Z
qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg logvolume `pc_ivlist' if statefip==`k'
qui predict rf_yhat`i'_`k', resid
qui replace rf_yhat`i' = rf_yhat`i'_`k' if statefip==`k'
}

drop rf_yhat`i'_*

* regress residualized y on residualized x2. Then, obtain rf_y_breve = y - delta_hat*x2

qui reg rf_yhat`i' *_x_hat_dem`i'
foreach exog of varlist  tmy1-tmy30 tmm1-tmm12 dat {
qui gen rf_y_breve`i'_b_`exog'=_b[`exog'_x_hat_dem`i']
}

qui gen rf_y_breve`i' = logvolume
foreach exog of varlist  tmy1-tmy30 tmm1-tmm12 dat {
qui replace rf_y_breve`i'= rf_y_breve`i' - (rf_y_breve`i'_b_`exog'*`exog')
}

* reg rf_y_breve on Z per cluster

qui gen rf_resid`i'=rf_y_breve`i'

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
 
qui reg rf_y_breve`i' `pc_ivlist' if statefip==`k'

foreach var of varlist `pc_ivlist' {
qui replace rf_b`i'_`var'=_b[`var'] if statefip==`k'
qui replace rf_resid`i'=rf_resid`i'-rf_b`i'_`var'*`var' if statefip==`k'
}
}

*standard errors
foreach var of varlist `pc_ivlist' {
qui gen rf_sum_errors`i'_`var'=.
}

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
mkmat `pc_ivlist' if statefip==`k' `options', matrix(Z) 
mkmat rf_resid`i' if statefip==`k' `options', matrix(e)
matrix zz=Z'*Z
matrix ze=Z'*e
matrix sum_comp=invsym(zz)*ze
local j=1
foreach var of varlist `pc_ivlist' {
local d`j'=sum_comp[`j',1]
qui replace rf_sum_errors`i'_`var'=`d`j'' if statefip==`k'
local j `++j'
}
}

foreach var of varlist `pc_ivlist' {
egen rf_reg`i'_`var' = mean(rf_b`i'_`var')
qui gen rf_dhat`i'_`var'=rf_b`i'_`var'-rf_reg`i'_`var'
}

qui gen rf_reg`i'_elasticity=0

foreach var of varlist `pc_ivlist' {
egen rf_var`i'_dhat_`var'=sd(rf_dhat`i'_`var') if pickone`i'_1==1
egen rf_var`i'_`var'=sd(rf_sum_errors`i'_`var') if pickone`i'_1==1
qui gen rf_se`i'_`var'=sqrt((rf_var`i'_dhat_`var'^2+rf_var`i'_`var'^2)/51)
qui gen rf_t`i'_`var'=rf_reg`i'_`var'/rf_se`i'_`var'
qui replace rf_reg`i'_elasticity=rf_reg`i'_elasticity+rf_reg`i'_`var'
}

corr rf_sum_errors`i'_* if pickone`i'_1==1, c
mat rf_sum_errors`i'=r(C)/51

corr rf_dhat`i'_* if pickone`i'_1==1, c
mat rf_dhat_errors`i'=r(C)/51

mat rf_errors`i'=rf_sum_errors`i'+rf_dhat_errors`i'

mata: st_matrix("rf_var`i'", rowsum(colsum(st_matrix("rf_errors`i'"))))
qui gen rf_var`i'_elasticity=rf_var`i'[1,1]
qui gen rf_se`i'_elasticity=sqrt(rf_var`i'_elasticity)
qui gen rf_t`i'_elasticity=rf_reg`i'_elasticity/rf_se`i'_elasticity

/* with weights */

gen wt_sq=sum(wt^2) if pickone`i'_1==1
replace wt_sq=sqrt(wt_sq) if pickone`i'_1==1

*** first stage ***

local m=1
foreach endo of varlist `pc_endoglist'{
foreach var of varlist `pc_ivlist' {
egen first_`m'_w_reg`i'_`var'=wtmean(first_`m'_b`i'_`var'), weight(wt)
qui gen first_`m'_w_dhat`i'_`var'=wt*(first_`m'_b`i'_`var'-first_`m'_w_reg`i'_`var')
qui gen first_`m'_w_sum_errors`i'_`var'=wt*first_`m'_sum_errors`i'_`var'
}

foreach var of varlist `pc_ivlist' {
qui gen first_`m'_w_se`i'_`var'=wt_sq*first_`m'_se`i'_`var'*sqrt(51)
qui gen first_`m'_w_t`i'_`var'=first_`m'_w_reg`i'_`var'/first_`m'_w_se`i'_`var'
}

statsby temp_first_w_fstat_`m'_`i'=e(F), by(statefip) saving(statsby`i'_`m'_w, replace): reg x_tilde`i'_`m' `pc_ivlist'

sort statefip
merge m:1 statefip using statsby`i'_`m'_w
capture egen pickone`i'_`m'_w = tag(statefip)
drop _merge 

hotelling temp_first_w_fstat_`m'_`i' [aweight=wt] if pickone`i'_1_w==1

qui gen first_w_fstat_`m'_`i'=r(T2)

local m `++m'
}

*** second stage ***

foreach var of varlist `pc_endoglist' {
egen w_reg`i'_`var'=wtmean(b`i'_`var'), weight(wt)
qui gen w_dhat`i'_`var'=wt*(b`i'_`var'-w_reg`i'_`var')
qui gen w_sum_errors`i'_`var'=wt*sum_errors`i'_`var'
}

qui gen w_reg`i'_elasticity=0

foreach var of varlist `pc_endoglist' {
qui gen w_se`i'_`var'=wt_sq*se`i'_`var'*sqrt(51)
qui gen w_t`i'_`var'=w_reg`i'_`var'/w_se`i'_`var'
qui replace w_reg`i'_elasticity=w_reg`i'_elasticity+w_reg`i'_`var'
}

qui gen w_se`i'_elasticity=wt_sq*se`i'_elasticity*sqrt(51)
qui gen w_t`i'_elasticity=w_reg`i'_elasticity/w_se`i'_elasticity


*** reduced form ***

 foreach var of varlist `pc_ivlist' {
egen rf_w_reg`i'_`var'=wtmean(rf_b`i'_`var'), weight(wt)
qui gen rf_w_dhat`i'_`var'=wt*(rf_b`i'_`var'-rf_w_reg`i'_`var')
qui gen rf_w_sum_errors`i'_`var'=wt*rf_sum_errors`i'_`var'
}

qui gen rf_w_reg`i'_elasticity=0

foreach var of varlist `pc_ivlist' {
qui gen rf_w_se`i'_`var'=wt_sq*rf_se`i'_`var'*sqrt(51)
qui gen rf_w_t`i'_`var'=rf_w_reg`i'_`var'/rf_w_se`i'_`var'
qui replace rf_w_reg`i'_elasticity=rf_w_reg`i'_elasticity+rf_w_reg`i'_`var'
}

qui gen rf_w_se`i'_elasticity=wt_sq*rf_se`i'_elasticity*sqrt(51)
qui gen rf_w_t`i'_elasticity=rf_w_reg`i'_elasticity/rf_w_se`i'_elasticity


**Results

outreg2 [reg_2sls reg_fe reg_2sls_w reg_fe_w] using "reg`i'_second.xls", replace ///
addstat("Elasticity_2SLS", `reg_elasticity_2sls',"se_2SLS",`se_elasticity_2sls',"Elasticity_FE", `reg_elasticity_fe',"se_FE", `se_elasticity_fe',"Elasticity_2SLS_W", `reg_elasticity_2sls_w',"se_2SLS_W",`se_elasticity_2sls_w',"Elasticity_FE_W", `reg_elasticity_fe_w',"se_FE_w",`se_elasticity_fe_w',"CD_2SLS",`fstat_cd_2sls',"CD_FE", `fstat_cd_fe',"CD_2SLS_w", `fstat_cd_2sls_w',"CD_FE_w", `fstat_cd_fe_w') excel nor2 dec(3) nocons drop( ) cttop("2SLS", "FE", "2SLS_W", "FE_W")

esttab reg_2sls_f_* reg_fe_f_* reg_2sls_w_f_* reg_fe_w_f_* using  "reg`i'_first.csv", b (%10.3f) se star(* 0.1 ** 0.05 *** 0.01)  se(3) noconstant drop( ) replace 

esttab reg_2sls_rf_* reg_fe_rf_* reg_2sls_w_rf_* reg_fe_w_rf_* using  "reg`i'_rf.csv", b (%10.3f) se star(* 0.1 ** 0.05 *** 0.01) se(3) noconstant drop( ) scalars(rf_reg_elasticity_2sls rf_se_elasticity_2sls rf_reg_elasticity_fe rf_se_elasticity_fe rf_w_reg_elasticity_2sls rf_w_se_elasticity_2sls rf_w_reg_elasticity_fe rf_w_se_elasticity_fe) replace 

*second stage PCIV
fsum reg*logprice se*logprice t*logprice w_reg*logprice w_se*logprice w_t*logprice reg*elasticity* w_reg*elasticity* se*elasticity w_se*elasticity, stat(mean)  f(%9.3f)

*first stage PCIV
fsum first_*_reg*logtax first_*_se*logtax first_*_t*logtax first_*_w_reg*logtax first_*_w_se*logtax first_*_w_t*logtax first*fstat*, stat(mean)  f(%9.3f)

*reduced form PCIV
fsum rf_reg*logtax rf_se*logtax rf_t*logtax rf_w_reg*logtax rf_w_se*logtax rf_w_t*logtax rf*elasticity*, stat(mean)  f(%9.3f)

save App_results`i'NUmy.dta, replace

}

********************************************************************************

*Table D.4. Estimated Elasticities Using Month and Year Fixed Effects

********************************************************************************		

clear
clear mata
clear matrix
set maxvar 30000

use App_results2NUmy.dta, clear
keep statename statefip time year month *reg* *se* *elasticity* *fstat* *_f_*
save App_results2NUmys.dta, replace

ren reg`i'_* reg_*`i'
ren se`i'_* se_*`i'

foreach i in reg se {
sum `i'_elasticity_2sls2
mat `i'a=(r(mean))
sum `i'_elasticity_fe2
mat `i'a=(`i'a,r(mean))
sum `i'2_elasticity
mat `i'a=(`i'a,r(mean))
sum `i'_elasticity_2sls_w2
mat `i'a=(`i'a,r(mean))
sum `i'_elasticity_fe_w2
mat `i'a=(`i'a,r(mean))
sum w_`i'2_elasticity
mat `i'a=(`i'a,r(mean))
}

foreach i in fstat {
sum `i'_cd_2sls2
mat `i'a=(r(mean))
sum `i'_cd_fe2
mat `i'a=(`i'a,r(mean))
sum first_`i'_1_2
mat `i'a=(`i'a,r(mean))
sum `i'_cd_2sls_w2
mat `i'a=(`i'a,r(mean))
sum `i'_cd_fe_w2
mat `i'a=(`i'a,r(mean))
sum first_w_`i'_1_2
mat `i'a=(`i'a,r(mean))

}
mat rownames rega= "Log price"
mat rownames fstata= "First-stage F-statistic"
mat rownames sea= " "

frmttable using "NUmy.tex", statmat(rega) replace  tex  ///
	ctitles(" ", "Without volume weights", "", "","Volume weighted", "", "" \"", "P2SLS","FEIV","PCIV","P2SLS","FEIV","PCIV" )  ///
	sdec(3, 3, 3, 3,3,3  )  multicol(1,2,3;1,5,3)
	frmttable using "NUmy.tex", statmat(sea) append va tex  ///
	ctitles(" ", "Without volume weights", "", "","Volume weighted", "", "" \"", "P2SLS","FEIV","PCIV","P2SLS","FEIV","PCIV" )  ///
	dbldiv("(") brackets("(",")") ///
	sdec(3, 3, 3, 3,3,3  ) addrows( " "," "," "," "," ", " ")  multicol(1,2,3;1,5,3)
	frmttable using "NUmy.tex", statmat(fstata) append va tex ///
	ctitles(" ", "Without volume weights", "", "","Volume weighted", "", "" \"", "P2SLS","FEIV","PCIV","P2SLS","FEIV","PCIV" )  ///
	addrows("Controls "," N"," N"," N"," N", "N", "N" \ " "," "," "," "," ", " ") ///
		sdec(2, 2, 2, 2,2,2 )  multicol(1,2,3;1,5,3)


