
********************************************************************************

*Table D.6. Regressions by PADD 

********************************************************************************

use temp_all.dta, clear
 local covars "real_inc_pc population licensed road_m  my_min_temp my_avg_temp my_max_temp my_rain_in unemployment"
local covars_miss "real_inc_pc_miss population_miss licensed_miss road_m_miss  my_min_temp_miss my_avg_temp_miss my_max_temp_miss my_rain_in_miss"
cap gen padd=.
replace padd=1 if (statename=="CT" | statename=="ME" | statename=="MA" | statename=="NH" | statename=="RI"| statename=="VT")
replace padd=2 if (statename=="DE" | statename=="DC" | statename=="MD" | statename=="NJ" | statename=="NY"| statename=="PA")
replace padd=3 if (statename=="FL" | statename=="GA" | statename=="NC" | statename=="SC" | statename=="WV"| statename=="VA")
replace padd=4 if (statename=="IL" | statename=="IN" | statename=="IA" | statename=="KS" | statename=="KY"| statename=="MI" | statename=="MN" ///
| statename=="MO" | statename=="NE" | statename=="ND" | statename=="SD"  | statename=="OH" | statename=="OK" | statename=="TN" | statename=="WI")
replace padd=5 if (statename=="AL" | statename=="AR" | statename=="LA" | statename=="MS" | statename=="NM"| statename=="TX")
replace padd=6 if (statename=="CO" | statename=="ID" | statename=="MT" | statename=="UT" | statename=="WY")
replace padd=7 if (statename=="AK" | statename=="AZ" | statename=="CA"  | statename=="HI" | statename=="NV"| statename=="OR" | statename=="WA")

bysort padd date: gen n=_N

local nn=n

local ivlist "dlogtax_rt"
local endoglist "dlogprice_rt"
local new_ivlist "new_logtax"
local new_endoglist "new_logprice"
local pc_ivlist "logtax"
local pc_endoglist "logprice"
local options ""
local lincomlist "dlogprice_rt"
local new_lincomlist "new_logprice"
local pc_lincomlist "logprice"
local rf_lincomlist "dlogtax_rt"
local rf_new_lincomlist "new_logtax"
local rf_pc_lincomlist "logtax"


*** first stage ***

* getting the residuals by regressing x1 and x2 on Z
xtset statefip

foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat {

qui gen `exog'_x_hat_dem=. 

qui sum padd
qui levelsof padd, local(levels) 
foreach k of local levels {
qui xtreg  `exog' `pc_ivlist' if padd==`k', fe
qui predict `exog'_x_hat_dem_`k', resid
qui replace `exog'_x_hat_dem = `exog'_x_hat_dem_`k' if padd==`k'
}

drop `exog'_x_hat_dem_*
}

local m=1
foreach endo of varlist `pc_endoglist' {
qui gen x_hat_dem_`m'=. 
qui sum padd
qui levelsof padd, local(levels) 
foreach k of local levels {
qui xtreg  `endo' `pc_ivlist' if padd==`k', fe
qui predict x_hat_dem_`m'_`var'_`k', resid
qui replace x_hat_dem_`m' = x_hat_dem_`m'_`var'_`k' if padd==`k'
}

drop x_hat_dem_`m'_*


* regress residualized x1 on residualized x2, then obtain x1_tilde = x1 - delta_hat*x2
qui xtreg x_hat_dem_`m' *_x_hat_dem, fe
foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat {
qui gen x_tilde_`m'_b_`exog'=_b[`exog'_x_hat_dem]
}

qui gen x_tilde_`m' = `endo'
foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat {
qui replace x_tilde_`m'= x_tilde_`m' - (x_tilde_`m'_b_`exog'*`exog')
}

foreach var of varlist `pc_ivlist' {
qui gen first_`m'_b_`var'=.
}
qui gen first_`m'_resid=x_tilde_`m'

* reg x1_tilde on z
qui sum padd
qui levelsof padd, local(levels) 
foreach k of local levels {
qui xtreg  x_tilde_`m' `pc_ivlist' if padd==`k', fe

* get the estimates from the first stage
foreach var of varlist `pc_ivlist' {
qui replace first_`m'_b_`var'=_b[`var'] if padd==`k'
qui replace first_`m'_resid=first_`m'_resid-first_`m'_b_`var'*`var' if padd==`k'
}
}

* recover the x_hat by adding gamma_hat*x2
qui gen x_hat_`m'=0
foreach var of varlist `pc_ivlist' {
qui replace x_hat_`m'= x_hat_`m' + first_`m'_b_`var'*`var'
}

foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat  {
qui replace x_hat_`m' = x_hat_`m' + x_tilde_`m'_b_`exog'*`exog'
}

*f-stats

statsby temp_first_fstat_`m'=e(F) N_clust=e(N_clust), by(padd) saving(statsby_`m', replace): reg x_tilde_`m' `pc_ivlist', cluster(statefip) 

sort padd
merge m:1 padd using statsby_`m'
capture egen pickone_`m' = tag(padd)
drop _merge 

hotelling temp_first_fstat_`m' if pickone_1==1

gen first_fstat_`m'=r(T2)
local m `++m'
}



*** second stage ***

foreach var of varlist `pc_endoglist' {
qui gen b_`var'=.

}
qui gen b_cons=.

qui gen yhat=.
cap gen N_clust=.
cap gen n_obs=.

* first obtain the residuals by regressing y and x2 on x1_hat per cluster
qui sum padd

qui levelsof padd, local(levels) 
foreach k of local levels {
qui xtreg logvolume x_hat_1 if padd==`k', fe
qui predict yhat_`k', resid
qui replace yhat = yhat_`k' if padd==`k'
replace n_obs=e(N) if padd==`k'

}

drop yhat_*

foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat  {

qui gen `exog'_2hat=.

qui sum padd
qui levelsof padd, local(levels) 
foreach k of local levels {
qui xtreg `exog' x_hat_1 if padd==`k', fe
qui predict `exog'_2hat_`k', resid
qui replace `exog'_2hat = `exog'_2hat_`k' if padd==`k'
}

drop `exog'_2hat_*

}

* regress residualized y on residualized x2. Then, obtain y_breve = y - delta_hat*x2

qui xtreg yhat *_2hat, fe
foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat  {
qui gen y_breve_b_`exog'=_b[`exog'_2hat]
}

qui gen y_breve = logvolume
foreach exog of varlist `covars' `covars_miss' tm1-tm359 dat  {
qui replace y_breve= y_breve - (y_breve_b_`exog'*`exog')
}

* reg y_breve on x1_hat per cluster

qui gen resid= y_breve
local pc_endoglist "logprice"
qui sum padd
qui levelsof padd, local(levels) 
foreach k of local levels {
 
 xtreg y_breve x_hat_1 if padd==`k', fe 
local m=1
foreach var of varlist `pc_endoglist' {
qui replace b_`var'=_b[x_hat_`m'] if padd==`k'
qui replace resid=resid-b_`var'*`var' if padd==`k'
local m `++m'
}
}


*standard errors
foreach var of varlist `pc_endoglist' {
qui gen sum_errors_`var'=.
}

qui sum padd
qui levelsof padd, local(levels) 
foreach k of local levels {
mkmat x_hat_* if padd==`k'  `options', matrix(X) 
mkmat resid if padd==`k' `options', matrix(e)
matrix xx=X'*X
matrix xe=X'*e
matrix sum_comp=invsym(xx)*xe
local j=1
foreach var of varlist `pc_endoglist' {
local d`j'=sum_comp[`j',1]
qui replace sum_errors_`var'=`d`j'' if padd==`k'
local j `++j'
}
}

foreach var of varlist `pc_endoglist' {
egen reg_`var' = mean(b_`var')
qui gen dhat_`var'=b_`var'-reg_`var'
}

foreach var of varlist `pc_endoglist' {
qui gen errors_`var'=dhat_`var'+sum_errors_`var'
}
gen se_padd_log_price=sqrt((sum_errors_logprice^2)/n_obs)
corr errors_* if pickone_1==1, c
mat errors=r(C)/`nn'

qui gen reg_elasticity=0

local j=1
foreach var of varlist `pc_endoglist' {
qui gen se_`var'=sqrt(errors[`j',`j'])
qui gen t_`var'=reg_`var'/se_`var'
qui replace reg_elasticity=reg_elasticity+reg_`var'
local j `++j'
}

mata: st_matrix("var", rowsum(colsum(st_matrix("errors"))))
qui gen se_elasticity=var[1,1]
qui replace se_elasticity=sqrt(se_elasticity)
qui gen t_elasticity=reg_elasticity/se_elasticity


**Results

fsum reg*logprice se*logprice t*logprice reg*elasticity* se*elasticity, stat(mean)  f(%9.3f)

save App_results_PADD.dta, replace


********************************************************************************

*Table D.6. PADD Table

********************************************************************************

use App_results_PADD.dta, clear
keep padd statename statefip time year month b_logprice se_logprice first_fstat_1_ n_obs N_clust 


foreach j in b_logprice se_logprice first_fstat_1_ n_obs N_clust {
forv  i=1/1  {
sum `j' if padd==`i'
mat `j'=(r(mean))
}
forv  i=2/7  {
sum `j' if padd==`i'
mat `j'=(`j',r(mean))
}
}


mat rownames b_logprice= "log price"
mat rownames first_fstat_1_= "F-statistic"
mat rownames N_clust= "Number of states "
mat rownames n_obs= "Observations"
mat rownames se_logprice= " "


mat ee= first_fstat_1_\N_clust\n_obs

	frmttable using "padd.tex", statmat(b_logprice) replace va tex  ///
	ctitles("PADD" "New","Central","Lower","Midwest","Gulf","Rocky", "West" \ "", "England", "Atlantic", "Atlantic", "", "Coast", "Mountains", "Coast")  ///
	sdec(3, 3, 3, 3,3,3,3  )
	frmttable using "padd.tex", statmat(se_logprice) append va tex  ///
	dbldiv(" (") brackets("(",")") ///
	sdec(3, 3, 3, 3,3,3,3  ) addrows( " "," "," "," "," ", " ", " ")
		frmttable using "padd.tex", statmat(ee) append va tex  ///
		sdec(2, 2, 2, 2,2,2, 2\ 0,0,0,0,0,0,0 \ 0,0,0,0,0,0,0 ) addrows( " "," "," "," "," ", " ", " ")




