
********************************************************************************

*Table F.1. Regressions for Replication

********************************************************************************

use "app.dta", clear

qui tab time, generate(tm)

*Few Last Definitions;
qui gen dunemployment = d.unemployment
qui gen TwoCentIncrease=(dstatetax>=2 & dstatetax!=.)
qui gen TwoCentDecrease=(dstatetax<=-2 & dstatetax!=.)
qui gen Iincrease = TwoCentIncrease * dlogtax

* IV using residual projection method;
foreach x of varlist dlogvolume dlogprice  dlogtax dunemployment {
 quietly reg `x' i.time
 qui predict `x'_rt, residuals
 quietly reg f.`x' i.time
 qui predict f1`x'_rt, residuals
 quietly reg f2.`x' i.time
 qui predict f2`x'_rt, residuals
 quietly reg l.`x' i.time
 qui predict l1`x'_rt, residuals
 quietly reg l2.`x' i.time
 qui predict l2`x'_rt, residuals
 quietly reg l3.`x' i.time
 qui predict l3`x'_rt, residuals
}

foreach x of varlist logvolume logprice logtax unemployment {
 quietly reg `x' i.time 
 qui predict new_`x', residuals
 quietly reg l.`x' i.time 
 qui predict lnew_`x', residuals
 quietly reg f.`x' i.time 
 qui predict fnew_`x', residuals
 quietly reg f2.`x' i.time
 qui predict f2new_`x', residuals
 quietly reg l2.`x' i.time
 qui predict l2new_`x', residuals
 }
 
 foreach x of varlist logvolume logprice logtax unemployment {
 qui gen f`x'=f.`x'
 qui gen f2`x'=f2.`x'
 qui gen l`x'=l.`x'
 qui gen l2`x'=l2.`x'
 }

bysort statefip: egen avg_volume=mean(volume)
egen tot=total(avg_volume)
qui gen wt=avg_volume*360/tot

save temp_all.dta, replace

foreach i in 2 6 7{

use temp_all.dta, clear

if `i'==2 {
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;
dis "Panel A: Contemporaneous log prices, just identified"
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;

local dcovars_rt "dunemployment_rt"
local dcovars_miss_rt ""
local  new_covars "new_unemployment"
local  new_covars_miss ""
local  covars "unemployment"
local  covars_miss ""
local ivlist "dlogtax_rt"
local endoglist "dlogprice_rt"
local new_ivlist "new_logtax"
local new_endoglist "new_logprice"
local pc_ivlist "logtax"
local pc_endoglist "logprice"
local options ""
local lincomlist "dlogprice_rt"
local new_lincomlist "new_logprice"
local pc_lincomlist "logprice"
local rf_lincomlist "dlogtax_rt"
local rf_new_lincomlist "new_logtax"
local rf_pc_lincomlist "logtax"


}

else if `i'==6{
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;
dis "Panel B: Additional lead and lag of log prices, just identified"
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;

local dcovars_rt "dunemployment_rt"
local dcovars_miss_rt ""
local  new_covars "new_unemployment"
local  new_covars_miss ""
local  covars "unemployment"
local  covars_miss ""
local ivlist "f2dlogtax_rt f1dlogtax_rt dlogtax_rt l1dlogtax_rt l2dlogtax_rt"
local endoglist "f1dlogprice_rt dlogprice_rt l1dlogprice_rt"
local new_ivlist "f2new_logtax fnew_logtax new_logtax lnew_logtax l2new_logtax"
local new_endoglist "fnew_logprice new_logprice lnew_logprice"
local pc_ivlist "f2logtax flogtax logtax llogtax l2logtax"
local pc_endoglist "flogprice logprice llogprice"
local options "& fnew_logtax!=. & lnew_logtax!=. & f2new_logtax!=. & l2new_logtax!=."
local lincomlist "f1dlogprice_rt+dlogprice_rt+l1dlogprice_rt"
local new_lincomlist "fnew_logprice+new_logprice+lnew_logprice"
local pc_lincomlist "flogprice+logprice+llogprice"
local rf_lincomlist "f2dlogtax_rt+f1dlogtax_rt+dlogtax_rt+l1dlogtax_rt+l2dlogtax_rt"
local rf_new_lincomlist "f2new_logtax+fnew_logtax+new_logtax+lnew_logtax+l2new_logtax"
local rf_pc_lincomlist "f2logtax+flogtax+logtax+llogtax+l2logtax"
}

else if `i'==7{
*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;
dis "Panel C: Additional lead and lag of log prices, over identified"
*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++;

local dcovars_rt "dunemployment_rt"
local dcovars_miss_rt ""
local  new_covars "new_unemployment"
local  new_covars_miss ""
local  covars "unemployment"
local  covars_miss ""
local ivlist "f1dlogtax_rt dlogtax_rt l1dlogtax_rt"
local endoglist "f1dlogprice_rt dlogprice_rt l1dlogprice_rt"
local new_ivlist "fnew_logtax new_logtax lnew_logtax"
local new_endoglist "fnew_logprice new_logprice lnew_logprice"
local pc_ivlist "flogtax logtax llogtax"
local pc_endoglist "flogprice logprice llogprice"
local options "& fnew_logtax!=. & lnew_logtax!=. "
local lincomlist "f1dlogprice_rt+dlogprice_rt+l1dlogprice_rt"
local new_lincomlist "fnew_logprice+new_logprice+lnew_logprice"
local pc_lincomlist "flogprice+logprice+llogprice"
local rf_lincomlist "f1dlogtax_rt+dlogtax_rt+l1dlogtax_rt"
local rf_new_lincomlist "fnew_logtax+new_logtax+lnew_logtax"
local rf_pc_lincomlist "flogtax+logtax+llogtax"

}

********************************** P2SLS ***************************************

/* without weights */

estimates clear
clear matrix
clear mata

*** first and second stage ***

eststo reg_2sls: qui ivreg2 dlogvolume_rt dunemployment_rt (`endoglist' = `ivlist'), cluster(statefip) savefirst saverf savefprefix( reg_2sls_f_) saverfprefix( reg_2sls_rf_) 
lincom `lincomlist' 

local reg_elasticity_2sls = r(estimate)
local se_elasticity_2sls = r(se)
gen reg_elasticity_2sls`i' = r(estimate)
gen se_elasticity_2sls`i' = r(se)

*** reduced form ***

est res reg_2sls_rf_*

lincom `rf_lincomlist'

estadd local rf_reg_elasticity_2sls = r(estimate)
estadd local rf_se_elasticity_2sls = r(se)

qui ivreg2 dlogvolume_rt dunemployment_rt (`endoglist' = `ivlist'), cluster(statefip)
local fstat_cd_2sls=e(widstat)
gen fstat_cd_2sls`i'=e(widstat)

foreach j in `endoglist' {
reg `j'  `ivlist' `dcovars_rt' `dcovars_miss_rt' , cluster(statefip)
cap gen reg_`ivlist'_f_2sls`i'=_b[`ivlist']
cap gen se_`ivlist'_f_2sls`i'=_se[`ivlist']
reg `j'  `ivlist' `dcovars_rt' `dcovars_miss_rt'  [pweight=wt], cluster(statefip)
cap gen reg_`ivlist'_f_w2sls`i'=_b[`ivlist']
cap gen se_`ivlist'_f_w2sls`i'=_se[`ivlist']
}


reg dlogvolume_rt  `ivlist' `dcovars_rt' `dcovars_miss_rt' , cluster(statefip)
foreach j in `ivlist' {
gen reg_`j'_rf_2sls`i'=_b[`j']
gen se_`j'_rf_2sls`i'=_se[`j']
}
reg dlogvolume_rt  `ivlist' `dcovars_rt' `dcovars_miss_rt'  [pweight=wt], cluster(statefip)
foreach j in `ivlist' {
gen reg_`j'_rf_w2sls`i'=_b[`j']
gen se_`j'_rf_w2sls`i'=_se[`j']

}

/* with weights */

*** first and second stage ***

eststo reg_2sls_w: qui ivreg2 dlogvolume_rt dunemployment_rt (`endoglist' = `ivlist') [pweight=wt], cluster(statefip) savefirst saverf savefprefix( reg_2sls_w_f_) saverfprefix( reg_2sls_w_rf_) 

lincom `lincomlist' 

local reg_elasticity_2sls_w = r(estimate)
local se_elasticity_2sls_w = r(se)

gen reg_elasticity_2sls_w`i' = r(estimate)
gen se_elasticity_2sls_w`i' = r(se)

*** reduced form ***

est res reg_2sls_w_rf_*

lincom `rf_lincomlist'

estadd local rf_w_reg_elasticity_2sls = r(estimate)
estadd local rf_w_se_elasticity_2sls = r(se)

qui ivreg2 dlogvolume_rt dunemployment_rt (`endoglist' = `ivlist') [pweight=wt], cluster(statefip)
local fstat_cd_2sls_w=e(widstat)
gen fstat_cd_2sls_w`i'=e(widstat)


********************************** FEIV ****************************************

/* without weights */

*** first and second stage ***

xtreg new_logvolume  `new_ivlist' `new_covars' `new_covars_miss'  , cluster(statefip) fe
foreach j in  `new_ivlist' {
gen reg_`j'_rf_fe`i'=_b[`j']
gen se_`j'_rf_fe`i'=_se[`j']
}

xtreg new_logvolume  `new_ivlist' `new_covars' `new_covars_miss' [pweight=wt], cluster(statefip) fe
foreach j in  `new_ivlist' {
gen reg_`j'_rf_wfe`i'=_b[`j']
gen se_`j'_rf_wfe`i'=_se[`j']
}


foreach j in `new_endoglist' {
xtreg `j'  `new_ivlist' `new_covars' `new_covars_miss'  , cluster(statefip) fe
cap gen reg_`new_ivlist'_f_fe`i'=_b[`new_ivlist']
cap gen se_`new_ivlist'_f_fe`i'=_se[`new_ivlist']
xtreg `j'  `new_ivlist' `new_covars' `new_covars_miss' [pweight=wt], cluster(statefip) fe
cap gen reg_`new_ivlist'_f_wfe`i'=_b[`new_ivlist']
cap gen se_`new_ivlist'_f_wfe`i'=_se[`new_ivlist']
}


xtset statefip time
eststo reg_fe: qui xtivreg2 new_logvolume new_unemployment (`new_endoglist'=`new_ivlist'), savefirst saverf savefprefix(reg_fe_f_) saverfprefix( reg_fe_rf_)  fe small cluster(statefip) 
lincom `new_lincomlist' 

local reg_elasticity_fe = r(estimate)
local se_elasticity_fe = r(se)

gen reg_elasticity_fe`i' = r(estimate)
gen se_elasticity_fe`i' = r(se)


*** reduced form ***

est res reg_fe_rf_*

lincom `rf_new_lincomlist'

local rf_reg_elasticity_fe = r(estimate)
local rf_se_elasticity_fe = r(se)

qui xtivreg2 new_logvolume new_unemployment (`new_endoglist'=`new_ivlist'), fe cluster(statefip)
local fstat_cd_fe=e(widstat)
gen fstat_cd_fe`i'=e(widstat)

/* with weights */

*** first and second stage ***

xtset statefip time
eststo reg_fe_w: qui xtivreg2 new_logvolume new_unemployment (`new_endoglist'=`new_ivlist') [pweight=wt], fe cluster(statefip)  savefirst saverf savefprefix( reg_fe_w_f_) saverfprefix( reg_fe_w_rf_) 

lincom `new_lincomlist' 

local reg_elasticity_fe_w = r(estimate)
local se_elasticity_fe_w = r(se)

gen reg_elasticity_fe_w`i' = r(estimate)
gen se_elasticity_fe_w`i' = r(se)

*** reduced form ***

est res reg_fe_w_rf_*

lincom `rf_new_lincomlist'

estadd local rf_w_reg_elasticity_fe = r(estimate)
estadd local rf_w_se_elasticity_fe = r(se)

qui xtivreg2 new_logvolume new_unemployment (`new_endoglist'=`new_ivlist') [pweight=wt], fe cluster(statefip) savefirst saverf savefprefix( reg_fe_w_f) saverfprefix( reg_fe_w_rf) 
local fstat_cd_fe_w=e(widstat)
gen fstat_cd_fe_w`i'=e(widstat)

********************************** PCIV ****************************************

/* without weights */

*** first stage ***

* getting the residuals by regressing x1 and x2 on Z


foreach exog of varlist unemployment tm1-tm230 {

qui gen `exog'_x_hat_dem`i'=. 

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg  `exog' `pc_ivlist' if statefip==`k'
qui predict `exog'_x_hat_dem`i'_`k', resid
qui replace `exog'_x_hat_dem`i' = `exog'_x_hat_dem`i'_`k' if statefip==`k'
}

drop `exog'_x_hat_dem`i'_*
}

local m=1
foreach endo of varlist `pc_endoglist' {
qui gen x_hat_dem`i'_`m'=. 
qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg  `endo' `pc_ivlist' if statefip==`k'
qui predict x_hat_dem`i'_`m'_`var'_`k', resid
qui replace x_hat_dem`i'_`m' = x_hat_dem`i'_`m'_`var'_`k' if statefip==`k'
}

drop x_hat_dem`i'_`m'_*


* regress residualized x1 on residualized x2, then obtain x1_tilde = x1 - delta_hat*x2
qui reg x_hat_dem`i'_`m' *_x_hat_dem`i'
foreach exog of varlist unemployment tm1-tm230 {
qui gen x_tilde`i'_`m'_b_`exog'=_b[`exog'_x_hat_dem`i']
}

qui gen x_tilde`i'_`m' = `endo'
foreach exog of varlist unemployment tm1-tm230 {
qui replace x_tilde`i'_`m'= x_tilde`i'_`m' - (x_tilde`i'_`m'_b_`exog'*`exog')
}

foreach var of varlist `pc_ivlist' {
qui gen first_`m'_b`i'_`var'=.
}
qui gen first_`m'_resid`i'=x_tilde`i'_`m'

* reg x1_tilde on z
qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg  x_tilde`i'_`m' `pc_ivlist' if statefip==`k'

* get the estimates from the first stage
foreach var of varlist `pc_ivlist' {
qui replace first_`m'_b`i'_`var'=_b[`var'] if statefip==`k'
qui replace first_`m'_resid`i'=first_`m'_resid`i'-first_`m'_b`i'_`var'*`var' if statefip==`k'
}
}

* recover the x_hat by adding gamma_hat*x2
qui gen x_hat`i'_`m'=0
foreach var of varlist `pc_ivlist' {
qui replace x_hat`i'_`m'= x_hat`i'_`m' + first_`m'_b`i'_`var'*`var'
}

foreach exog of varlist unemployment tm1-tm230 {
qui replace x_hat`i'_`m' = x_hat`i'_`m' + x_tilde`i'_`m'_b_`exog'*`exog'
}

*f-stats

statsby temp_first_fstat_`m'_`i'=e(F), by(statefip) saving(statsby`i'_`m', replace): reg x_tilde`i'_`m' `pc_ivlist'

sort statefip
merge m:1 statefip using statsby`i'_`m'
capture egen pickone`i'_`m' = tag(statefip)
drop _merge 

hotelling temp_first_fstat_`m'_`i' if pickone`i'_1==1

qui gen first_fstat_`m'_`i'=r(T2)


*standard errors
foreach var of varlist `pc_ivlist' {
egen first_`m'_reg`i'_`var' = mean(first_`m'_b`i'_`var')
qui gen first_`m'_dhat`i'_`var'=first_`m'_b`i'_`var'-first_`m'_reg`i'_`var'
qui gen first_`m'_sum_errors`i'_`var'=.
}

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
mkmat `pc_ivlist' if statefip==`k' `options', matrix(Z) 
mkmat first_`m'_resid`i' if statefip==`k' `options', matrix(e)
matrix zz=Z'*Z
matrix ze=Z'*e
matrix sum_comp=invsym(zz)*ze
local j=1
foreach var of varlist `pc_ivlist' {
local d`j'=sum_comp[`j',1]
qui replace first_`m'_sum_errors`i'_`var'=`d`j'' if statefip==`k'
local j `++j'
}
}

foreach var of varlist `pc_ivlist' {
egen first_`m'_var`i'_dhat_`var'=sd(first_`m'_dhat`i'_`var') if pickone`i'_1==1
egen first_`m'_var`i'_`var'=sd(first_`m'_sum_errors`i'_`var') if pickone`i'_1==1
qui gen first_`m'_se`i'_`var'=sqrt((first_`m'_var`i'_dhat_`var'^2+first_`m'_var`i'_`var'^2)/51)
qui gen first_`m'_t`i'_`var'=first_`m'_reg`i'_`var'/first_`m'_se`i'_`var'
}
local m `++m'
}

*** second stage ***

foreach var of varlist `pc_endoglist' {
qui gen b`i'_`var'=.
}
qui gen b`i'_cons=.

qui gen yhat`i'=.

* first obtain the residuals by regressing y and x2 on x1_hat per cluster
qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg logvolume x_hat`i'_* if statefip==`k'
qui predict yhat`i'_`k', resid
qui replace yhat`i' = yhat`i'_`k' if statefip==`k'
}

drop yhat`i'_*

foreach exog of varlist unemployment tm1-tm230 {

qui gen `exog'_2hat`i'=.

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg `exog' x_hat`i'_* if statefip==`k'
qui predict `exog'_2hat`i'_`k', resid
qui replace `exog'_2hat`i' = `exog'_2hat`i'_`k' if statefip==`k'
}

drop `exog'_2hat`i'_*

}

* regress residualized y on residualized x2. Then, obtain y_breve = y - delta_hat*x2

qui reg yhat`i' *_2hat`i'
foreach exog of varlist unemployment tm1-tm230 {
qui gen y_breve`i'_b_`exog'=_b[`exog'_2hat`i']
}

qui gen y_breve`i' = logvolume
foreach exog of varlist unemployment tm1-tm230 {
qui replace y_breve`i'= y_breve`i' - (y_breve`i'_b_`exog'*`exog')
}

* reg y_breve on x1_hat per cluster

qui gen resid`i'= y_breve`i'

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
 
qui reg y_breve`i' x_hat`i'_* if statefip==`k'
local m=1
foreach var of varlist `pc_endoglist' {
qui replace b`i'_`var'=_b[x_hat`i'_`m'] if statefip==`k'
qui replace resid`i'=resid`i'-b`i'_`var'*`var' if statefip==`k'
local m `++m'
}
}


*standard errors
foreach var of varlist `pc_endoglist' {
qui gen sum_errors`i'_`var'=.
}

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
mkmat x_hat`i'_* if statefip==`k'  `options', matrix(X) 
mkmat resid`i' if statefip==`k' `options', matrix(e)
matrix xx=X'*X
matrix xe=X'*e
matrix sum_comp=invsym(xx)*xe
local j=1
foreach var of varlist `pc_endoglist' {
local d`j'=sum_comp[`j',1]
qui replace sum_errors`i'_`var'=`d`j'' if statefip==`k'
local j `++j'
}
}

foreach var of varlist `pc_endoglist' {
egen reg`i'_`var' = mean(b`i'_`var')
qui gen dhat`i'_`var'=b`i'_`var'-reg`i'_`var'
}

qui gen reg`i'_elasticity=0

foreach var of varlist `pc_endoglist' {
egen var`i'_dhat_`var'=sd(dhat`i'_`var') if pickone`i'_1==1
egen var`i'_`var'=sd(sum_errors`i'_`var') if pickone`i'_1==1
qui gen se`i'_`var'=sqrt((var`i'_dhat_`var'^2+var`i'_`var'^2)/51)
qui gen t`i'_`var'=reg`i'_`var'/se`i'_`var'
qui replace reg`i'_elasticity=reg`i'_elasticity+reg`i'_`var'
}

corr sum_errors`i'_* if pickone`i'_1==1, c
mat sum_errors`i'=r(C)/51

corr dhat`i'_* if pickone`i'_1==1, c
mat dhat_errors`i'=r(C)/51

mat errors`i'=sum_errors`i'+dhat_errors`i'

mata: st_matrix("var`i'", rowsum(colsum(st_matrix("errors`i'"))))
qui gen var`i'_elasticity=var`i'[1,1]
qui gen se`i'_elasticity=sqrt(var`i'_elasticity)
qui gen t`i'_elasticity=reg`i'_elasticity/se`i'_elasticity

*** reduced form ***

foreach var of varlist `pc_ivlist' {
qui gen rf_b`i'_`var'=.
}
qui gen rf_b`i'_cons=.
qui gen rf_yhat`i'=.

* first obtain the residuals by regressing y and x2 on Z
qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
qui reg logvolume `pc_ivlist' if statefip==`k'
qui predict rf_yhat`i'_`k', resid
qui replace rf_yhat`i' = rf_yhat`i'_`k' if statefip==`k'
}

drop rf_yhat`i'_*

* regress residualized y on residualized x2. Then, obtain rf_y_breve = y - delta_hat*x2

qui reg rf_yhat`i' *_x_hat_dem`i'
foreach exog of varlist unemployment tm1-tm230 {
qui gen rf_y_breve`i'_b_`exog'=_b[`exog'_x_hat_dem`i']
}

qui gen rf_y_breve`i' = logvolume
foreach exog of varlist unemployment tm1-tm230 {
qui replace rf_y_breve`i'= rf_y_breve`i' - (rf_y_breve`i'_b_`exog'*`exog')
}

* reg rf_y_breve on Z per cluster

qui gen rf_resid`i'=rf_y_breve`i'

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
 
qui reg rf_y_breve`i' `pc_ivlist' if statefip==`k'

foreach var of varlist `pc_ivlist' {
qui replace rf_b`i'_`var'=_b[`var'] if statefip==`k'
qui replace rf_resid`i'=rf_resid`i'-rf_b`i'_`var'*`var' if statefip==`k'
}
}

*standard errors
foreach var of varlist `pc_ivlist' {
qui gen rf_sum_errors`i'_`var'=.
}

qui sum statefip
qui levelsof statefip, local(levels) 
foreach k of local levels {
mkmat `pc_ivlist' if statefip==`k' `options', matrix(Z) 
mkmat rf_resid`i' if statefip==`k' `options', matrix(e)
matrix zz=Z'*Z
matrix ze=Z'*e
matrix sum_comp=invsym(zz)*ze
local j=1
foreach var of varlist `pc_ivlist' {
local d`j'=sum_comp[`j',1]
qui replace rf_sum_errors`i'_`var'=`d`j'' if statefip==`k'
local j `++j'
}
}

foreach var of varlist `pc_ivlist' {
egen rf_reg`i'_`var' = mean(rf_b`i'_`var')
qui gen rf_dhat`i'_`var'=rf_b`i'_`var'-rf_reg`i'_`var'
}

qui gen rf_reg`i'_elasticity=0

foreach var of varlist `pc_ivlist' {
egen rf_var`i'_dhat_`var'=sd(rf_dhat`i'_`var') if pickone`i'_1==1
egen rf_var`i'_`var'=sd(rf_sum_errors`i'_`var') if pickone`i'_1==1
qui gen rf_se`i'_`var'=sqrt((rf_var`i'_dhat_`var'^2+rf_var`i'_`var'^2)/51)
qui gen rf_t`i'_`var'=rf_reg`i'_`var'/rf_se`i'_`var'
qui replace rf_reg`i'_elasticity=rf_reg`i'_elasticity+rf_reg`i'_`var'
}

corr rf_sum_errors`i'_* if pickone`i'_1==1, c
mat rf_sum_errors`i'=r(C)/51

corr rf_dhat`i'_* if pickone`i'_1==1, c
mat rf_dhat_errors`i'=r(C)/51

mat rf_errors`i'=rf_sum_errors`i'+rf_dhat_errors`i'

mata: st_matrix("rf_var`i'", rowsum(colsum(st_matrix("rf_errors`i'"))))
qui gen rf_var`i'_elasticity=rf_var`i'[1,1]
qui gen rf_se`i'_elasticity=sqrt(rf_var`i'_elasticity)
qui gen rf_t`i'_elasticity=rf_reg`i'_elasticity/rf_se`i'_elasticity

/* with weights */

gen wt_sq=sum(wt^2) if pickone`i'_1==1
replace wt_sq=sqrt(wt_sq) if pickone`i'_1==1


*** first stage ***

local m=1
foreach endo of varlist `pc_endoglist'{
foreach var of varlist `pc_ivlist' {
egen first_`m'_w_reg`i'_`var'=wtmean(first_`m'_b`i'_`var'), weight(wt)
qui gen first_`m'_w_dhat`i'_`var'=wt*(first_`m'_b`i'_`var'-first_`m'_w_reg`i'_`var')
qui gen first_`m'_w_sum_errors`i'_`var'=wt*first_`m'_sum_errors`i'_`var'
}

foreach var of varlist `pc_ivlist' {
qui gen first_`m'_w_se`i'_`var'=wt_sq*first_`m'_se`i'_`var'*sqrt(51)
qui gen first_`m'_w_t`i'_`var'=first_`m'_w_reg`i'_`var'/first_`m'_w_se`i'_`var'
}

statsby temp_first_w_fstat_`m'_`i'=e(F), by(statefip) saving(statsby`i'_`m'_w, replace): reg x_tilde`i'_`m' `pc_ivlist'

sort statefip
merge m:1 statefip using statsby`i'_`m'_w
capture egen pickone`i'_`m'_w = tag(statefip)
drop _merge 

hotelling temp_first_w_fstat_`m'_`i' [aweight=wt] if pickone`i'_1_w==1

qui gen first_w_fstat_`m'_`i'=r(T2)

local m `++m'
}

*** second stage ***

foreach var of varlist `pc_endoglist' {
egen w_reg`i'_`var'=wtmean(b`i'_`var'), weight(wt)
qui gen w_dhat`i'_`var'=wt*(b`i'_`var'-w_reg`i'_`var')
qui gen w_sum_errors`i'_`var'=wt*sum_errors`i'_`var'
}

qui gen w_reg`i'_elasticity=0

foreach var of varlist `pc_endoglist' {
qui gen w_se`i'_`var'=wt_sq*se`i'_`var'*sqrt(51)
qui gen w_t`i'_`var'=w_reg`i'_`var'/w_se`i'_`var'
qui replace w_reg`i'_elasticity=w_reg`i'_elasticity+w_reg`i'_`var'
}

qui gen w_se`i'_elasticity=wt_sq*se`i'_elasticity*sqrt(51)
qui gen w_t`i'_elasticity=w_reg`i'_elasticity/w_se`i'_elasticity


*** reduced form ***

 foreach var of varlist `pc_ivlist' {
egen rf_w_reg`i'_`var'=wtmean(rf_b`i'_`var'), weight(wt)
qui gen rf_w_dhat`i'_`var'=wt*(rf_b`i'_`var'-rf_w_reg`i'_`var')
qui gen rf_w_sum_errors`i'_`var'=wt*rf_sum_errors`i'_`var'
}

qui gen rf_w_reg`i'_elasticity=0

foreach var of varlist `pc_ivlist' {
qui gen rf_w_se`i'_`var'=wt_sq*rf_se`i'_`var'*sqrt(51)
qui gen rf_w_t`i'_`var'=rf_w_reg`i'_`var'/rf_w_se`i'_`var'
qui replace rf_w_reg`i'_elasticity=rf_w_reg`i'_elasticity+rf_w_reg`i'_`var'
}

qui gen rf_w_se`i'_elasticity=wt_sq*rf_se`i'_elasticity*sqrt(51)
qui gen rf_w_t`i'_elasticity=rf_w_reg`i'_elasticity/rf_w_se`i'_elasticity


**Results

outreg2 [reg_2sls reg_fe reg_2sls_w reg_fe_w] using "reg`i'_old_second.xls", replace ///
addstat("Elasticity_2SLS", `reg_elasticity_2sls',"se",`se_elasticity_2sls',"Elasticity_FE", `reg_elasticity_fe',"se", `se_elasticity_fe',"Elasticity_2SLS_W", `reg_elasticity_2sls_w',"se",`se_elasticity_2sls_w',"Elasticity_FE_W", `reg_elasticity_fe_w',"se",`se_elasticity_fe_w',"CD_2SLS",`fstat_cd_2sls',"CD_FE", `fstat_cd_fe',"CD_2SLS_w", `fstat_cd_2sls_w',"CD_FE_w", `fstat_cd_fe_w') excel nor2 dec(3) nocons drop(dunemployment_rt new_unemployment) cttop("2SLS", "FE", "2SLS_W", "FE_W")

esttab reg_2sls_f_* reg_fe_f_* reg_2sls_w_f_* reg_fe_w_f_* using  "reg`i'_old_first.csv", b (%10.3f) se star(* 0.1 ** 0.05 *** 0.01)  se(3) noconstant drop(dunemployment_rt new_unemployment) replace 

esttab reg_2sls_rf_* reg_fe_rf_* reg_2sls_w_rf_* reg_fe_w_rf_* using  "reg`i'_old_rf.csv", b (%10.3f) se star(* 0.1 ** 0.05 *** 0.01) se(3) noconstant drop(dunemployment_rt new_unemployment) scalars(rf_reg_elasticity_2sls rf_se_elasticity_2sls rf_reg_elasticity_fe rf_se_elasticity_fe rf_w_reg_elasticity_2sls rf_w_se_elasticity_2sls rf_w_reg_elasticity_fe rf_w_se_elasticity_fe) replace 

save App_old_results`i'.dta, replace

}


********************************************************************************

*Table F.1. Replication Table

********************************************************************************

clear
clear mata
clear matrix
set maxvar 30000

foreach v in 6 7 {
use App_old_results`v'.dta, clear
keep statename statefip time year month *reg* se* *elasticity* *fstat* *_f_*
save App_old_results`v's.dta, replace
}

use App_old_results2.dta, clear

keep statename statefip time year month *reg* *se* *elasticity* *fstat* *_f_*
foreach v in 6 7 {
merge 1:1 statefip time using App_old_results`v's.dta, gen(mrg`v')
}
save App_old_results2s.dta, replace

foreach i in 2 6 7 {
ren reg`i'_* reg_*`i'
ren se`i'_* se_*`i'
}

foreach j in 2 6 7 {
foreach i in reg se {
sum `i'_elasticity_2sls`j'
mat `i'a`j'=(r(mean))
sum `i'_elasticity_fe`j'
mat `i'a`j'=(`i'a`j',r(mean))
sum `i'_elasticity`j'
mat `i'a`j'=(`i'a`j',r(mean))
sum `i'_elasticity_2sls_w`j'
mat `i'a`j'=(`i'a`j',r(mean))
sum `i'_elasticity_fe_w`j'
mat `i'a`j'=(`i'a`j',r(mean))
sum w_`i'`j'_elasticity
mat `i'a`j'=(`i'a`j',r(mean))
}
}
foreach j in 2 6 7 {
foreach i in fstat {
sum `i'_cd_2sls`j'
mat `i'a`j'=(r(mean))
sum `i'_cd_fe`j'
mat `i'a`j'=(`i'a`j',r(mean))
sum first_`i'_1_`j'
mat `i'a`j'=(`i'a`j',r(mean))
sum `i'_cd_2sls_w`j'
mat `i'a`j'=(`i'a`j',r(mean))
sum `i'_cd_fe_w`j'
mat `i'a`j'=(`i'a`j',r(mean))
sum first_w_`i'_1_`j'
mat `i'a`j'=(`i'a`j',r(mean))

}
mat rownames rega`j'= "Log price"
mat rownames fstata`j'= "First-stage F-statistic"
mat rownames sea`j'= " "
}

	
			foreach v in 2 {
		frmttable using "mainREP.tex", statmat(rega`v') replace va tex  ///
			ctitles("Panel A: Contemporaneous just identified", " ", " ", " ", " ", " ", " " \" ", " ", " ", " ", " ", " ", " "\ " ", "Without volume weights", "", "","Volume weighted", "", "" \"",  "P2SLS","FEIV","PCIV","P2SLS","FEIV","PCIV" )  ///
	sdec(3, 3, 3, 3,3,3  ) multicol(1,1,7;3,2,3;3,5,3) 
		frmttable using "mainREP.tex", statmat(sea`v') append va tex  ///
	 dbldiv(" (") brackets("(",")") ///
	sdec(3, 3, 3, 3,3,3  ) multicol(1,1,7;3,2,3;3,5,3)
	frmttable using "mainREP.tex", statmat(fstata`v') append va tex /*addrows("Controls "," Y"," Y"," Y"," Y", "Y", "Y")*/ ///
		sdec(2, 2, 2, 2,2,2 ) multicol(1,1,7;3,2,3;3,5,3)
}
		
		foreach v in 6 7{
		frmttable using "mainREP.tex", statmat(rega`v') append va tex  ///
					ctitles("`v'", " ", " ", " ", " ", " ", " "\ " ",  "Without volume weights", "", "","Volume weighted", "", "" \"", "P2SLS","FEIV","PCIV","P2SLS","FEIV","PCIV" )  ///
	sdec(3, 3, 3, 3,3,3  ) multicol(1,1,7;3,2,3;3,5,3)
		frmttable using "mainREP.tex", statmat(sea`v') append va tex  ///
	 dbldiv(" (") brackets("(",")") ///
	sdec(3, 3, 3, 3,3,3  ) multicol(1,1,7;3,2,3;3,5,3)
	frmttable using "mainREP.tex", statmat(fstata`v') append va tex /*addrows("Controls "," Y"," Y"," Y"," Y", "Y", "Y")*/ ///
		sdec(2, 2, 2, 2,2,2 ) multicol(1,1,7;3,2,3;3,5,3)
}
