
use gastax_merged_dataset.dta, clear
drop if year<1989 |year>2019
ren state_fips statefip
replace statefip=2 if state_name=="ALASKA"
replace statefip=9 if state_name=="CONNECTICUT"
duplicates drop
ren _merge mrgCOV
save covariates.dta, replace

use new_app.dta, clear
merge 1:1 statefip year month using covariates.dta, gen(mrgTAX) 
drop if mrgTAX==2

ren *monthly* *my*
ren *inches* *in* 
ren *income* *inc*
ren *licensed_driver* *licensed*
ren *road_mileage* *road_m*
xtset statefip time
foreach i in real_inc_pc population licensed road_m  ///
  my_min_temp my_avg_temp my_max_temp my_rain_in {
  ren `i' `i'2
  cap gen `i'=log(`i')
cap gen d`i'=`i'-l.`i'
cap gen `i'_miss=(`i'==.)
replace `i'=0 if `i'==.
cap gen d`i'_miss=(d`i'==.)
replace d`i'=0 if d`i'==.
}

*qui generate a data dummy and t2 and t3

qui gen dat=0
qui replace dat=1 if (year==2008 & month>3 | year>2008) 
qui tab time, generate(tm)

*Few Last Definitions;
qui gen dunemployment = d.unemployment
qui gen TwoCentIncrease=(dstatetax>=2 & dstatetax!=.)
qui gen TwoCentDecrease=(dstatetax<=-2 & dstatetax!=.)
qui gen Iincrease = TwoCentIncrease * dlogtax

local dcovars real_inc_pc population licensed road_m dunemployment dmy_min_temp dmy_avg_temp dmy_max_temp dmy_rain_in real_inc_pc_miss population_miss licensed_miss road_m_miss dmy_min_temp_miss dmy_avg_temp_miss dmy_max_temp_miss dmy_rain_in_miss

* IV using residual projection method;
foreach x of varlist dlogvolume dlogprice  dlogtax  `dcovars' {
 quietly reg `x' i.time
 qui predict `x'_rt, residuals
 quietly reg f.`x' i.time
 qui predict f1`x'_rt, residuals
 quietly reg f2.`x' i.time
 qui predict f2`x'_rt, residuals
 quietly reg l.`x' i.time
 qui predict l1`x'_rt, residuals
 quietly reg l2.`x' i.time
 qui predict l2`x'_rt, residuals
 quietly reg l3.`x' i.time
 qui predict l3`x'_rt, residuals
}
local covars "real_inc_pc population licensed road_m  my_min_temp my_avg_temp my_max_temp my_rain_in unemployment"
local covars_miss "real_inc_pc_miss population_miss licensed_miss road_m_miss  my_min_temp_miss my_avg_temp_miss my_max_temp_miss my_rain_in_miss"
foreach x of varlist logvolume logprice logtax  `covars' `covars_miss' {
 quietly reg `x' i.time 
 qui predict new_`x', residuals
 quietly reg l.`x' i.time 
 qui predict lnew_`x', residuals
 quietly reg f.`x' i.time 
 qui predict fnew_`x', residuals
 quietly reg f2.`x' i.time
 qui predict f2new_`x', residuals
 quietly reg l2.`x' i.time
 qui predict l2new_`x', residuals
 }
 
 foreach x of varlist logvolume logprice logtax  {
 qui gen f`x'=f.`x'
 qui gen f2`x'=f2.`x'
 qui gen l`x'=l.`x'
 qui gen l2`x'=l2.`x'
 }

bysort statefip: egen avg_volume=mean(volume)
egen tot=total(avg_volume)
qui gen wt=avg_volume*360/tot

save temp_all.dta, replace